# Fechos para Correspondência Oficial — Manual de Redação 3ª edição (2018)

## Regra Principal

Na 3ª edição do Manual de Redação, apenas **DOIS fechos** são admitidos
para a correspondência oficial:

### Respeitosamente,

Usado quando o remetente se dirige a autoridade **SUPERIOR**.

Exemplos:
- Servidor → Diretor
- Diretor → Secretário
- Secretário → Ministro
- Qualquer autoridade → Presidente da República

### Atenciosamente,

Usado quando o remetente se dirige a autoridade de **mesma hierarquia** ou **inferior**.

Exemplos:
- Diretor → Diretor (mesmo nível)
- Secretário → Coordenador
- Ministro → Secretário

## Fechos por Tipo de Documento

| Documento | Fecho |
|-----------|-------|
| Ofício (para superior) | Respeitosamente, |
| Ofício (mesmo nível/inferior) | Atenciosamente, |
| Parecer | É o parecer, s.m.j. |
| Portaria | Sem fecho |
| Despacho | Sem fecho obrigatório |
| Nota Técnica | Sem fecho obrigatório |
| Ata | "Nada mais havendo a tratar..." |

## Expressões PROIBIDAS como fecho

NÃO usar:
- "Sem mais para o momento"
- "Subscrevemo-nos"
- "Cordialmente"
- "Com os protestos de elevada estima e distinta consideração"
- "Aproveitamos o ensejo para apresentar votos de estima"

## Formato do Fecho

1. Fecho seguido de **vírgula**
2. Nova linha com nome e cargo do signatário
3. Uma linha em branco entre o último parágrafo e o fecho
